@@ -4,16 +4,17 @@
 import os
 from flask import Flask
 from flask_frozen import Freezer
-from flask_assets import Environment
+# from flask_assets import Environment
 from flask_flatpages import FlatPages
 from flask_babel import Babel
 from whiskey.flatpandoc import FlatPagesPandoc
 
 app = Flask(__name__)
 app.config.from_pyfile('settings.py')
+app.static_folder = app.config['STATIC_FOLDER']
 
 
-assets = Environment(app)
+# assets = Environment(app)
 babel = Babel(app)
 flatpages = FlatPages(app)
 FlatPagesPandoc(app.config['PANDOC_MD_FORMAT'],
@@ -23,7 +24,7 @@ FlatPagesPandoc(app.config['PANDOC_MD_FORMAT'],
                 )
 freezer = Freezer(app)
 
-import whiskey.assets
+# import whiskey.assets
 import whiskey.templates
 import whiskey.views
 import whiskey.commands
